==> duckdb-0.2.6.tar.gz: duckdb-0.2.6/duckdb/amalgamation-1.cpp <==
#include "src/catalog/catalog.cpp"

#include "src/catalog/catalog_entry.cpp"

#include "src/catalog/catalog_entry/copy_function_catalog_entry.cpp"

#include "src/catalog/catalog_entry/index_catalog_entry.cpp"

#include "src/catalog/catalog_entry/macro_catalog_entry.cpp"

#include "src/catalog/catalog_entry/pragma_function_catalog_entry.cpp"

#include "src/catalog/catalog_entry/schema_catalog_entry.cpp"

#include "src/catalog/catalog_entry/sequence_catalog_entry.cpp"

#include "src/catalog/catalog_entry/table_catalog_entry.cpp"

#include "src/catalog/catalog_entry/table_function_catalog_entry.cpp"

#include "src/catalog/catalog_entry/view_catalog_entry.cpp"

#include "src/catalog/catalog_set.cpp"

#include "src/catalog/default/default_functions.cpp"

#include "src/catalog/default/default_schemas.cpp"

#include "src/catalog/default/default_views.cpp"

#include "src/catalog/dependency_manager.cpp"

#include "src/common/allocator.cpp"

#include "src/common/assert.cpp"

#include "src/common/bit_operations.cpp"

#include "src/common/checksum.cpp"

#include "src/common/constants.cpp"

#include "src/common/crypto/md5.cpp"

#include "src/common/cycle_counter.cpp"

#include "src/common/enums/catalog_type.cpp"

#include "src/common/enums/expression_type.cpp"

#include "src/common/enums/join_type.cpp"

#include "src/common/enums/logical_operator_type.cpp"

#include "src/common/enums/physical_operator_type.cpp"

#include "src/common/enums/relation_type.cpp"

#include "src/common/enums/statement_type.cpp"

#include "src/common/exception.cpp"

#include "src/common/exception_format_value.cpp"

#include "src/common/file_buffer.cpp"

#include "src/common/file_system.cpp"

#include "src/common/fstream_util.cpp"

#include "src/common/gzip_stream.cpp"

#include "src/common/limits.cpp"

#include "src/common/operator/cast_operators.cpp"

#include "src/common/printer.cpp"

#include "src/common/progress_bar.cpp"

#include "src/common/serializer.cpp"

#include "src/common/serializer/buffered_deserializer.cpp"

#include "src/common/serializer/buffered_file_reader.cpp"

#include "src/common/serializer/buffered_file_writer.cpp"

#include "src/common/serializer/buffered_serializer.cpp"

#include "src/common/string_util.cpp"

#include "src/common/tree_renderer.cpp"

#include "src/common/types.cpp"

#include "src/common/types/blob.cpp"

#include "src/common/types/cast_helpers.cpp"

#include "src/common/types/chunk_collection.cpp"

#include "src/common/types/data_chunk.cpp"

#include "src/common/types/date.cpp"

#include "src/common/types/decimal.cpp"

#include "src/common/types/hash.cpp"

#include "src/common/types/hugeint.cpp"

#include "src/common/types/hyperloglog.cpp"

#include "src/common/types/interval.cpp"

#include "src/common/types/null_value.cpp"

#include "src/common/types/row_data_collection.cpp"

#include "src/common/types/selection_vector.cpp"

#include "src/common/types/string_heap.cpp"

#include "src/common/types/string_type.cpp"

#include "src/common/types/time.cpp"

#include "src/common/types/timestamp.cpp"

#include "src/common/types/validity_mask.cpp"

#include "src/common/types/value.cpp"

#include "src/common/types/vector.cpp"

#include "src/common/types/vector_buffer.cpp"

#include "src/common/types/vector_constants.cpp"

#include "src/common/value_operations/comparison_operations.cpp"

#include "src/common/value_operations/hash.cpp"

#include "src/common/value_operations/numeric_operations.cpp"

#include "src/common/vector_operations/boolean_operators.cpp"

#include "src/common/vector_operations/comparison_operators.cpp"

#include "src/common/vector_operations/gather.cpp"

#include "src/common/vector_operations/generators.cpp"

#include "src/common/vector_operations/is_distinct_from.cpp"

#include "src/common/vector_operations/null_operations.cpp"

#include "src/common/vector_operations/numeric_inplace_operators.cpp"

#include "src/common/vector_operations/vector_cast.cpp"

#include "src/common/vector_operations/vector_copy.cpp"

#include "src/common/vector_operations/vector_hash.cpp"

#include "src/common/vector_operations/vector_storage.cpp"

#include "src/execution/adaptive_filter.cpp"

#include "src/execution/aggregate_hashtable.cpp"

#include "src/execution/base_aggregate_hashtable.cpp"

#include "src/execution/column_binding_resolver.cpp"

#include "src/execution/expression_executor.cpp"

#include "src/execution/expression_executor/execute_between.cpp"

#include "src/execution/expression_executor/execute_case.cpp"

#include "src/execution/expression_executor/execute_cast.cpp"

#include "src/execution/expression_executor/execute_comparison.cpp"

#include "src/execution/expression_executor/execute_conjunction.cpp"

#include "src/execution/expression_executor/execute_constant.cpp"

#include "src/execution/expression_executor/execute_function.cpp"

#include "src/execution/expression_executor/execute_operator.cpp"

#include "src/execution/expression_executor/execute_parameter.cpp"

#include "src/execution/expression_executor/execute_reference.cpp"

#include "src/execution/expression_executor_state.cpp"

#include "src/execution/index/art/art.cpp"

#include "src/execution/index/art/art_key.cpp"

#include "src/execution/index/art/leaf.cpp"

#include "src/execution/index/art/node.cpp"

#include "src/execution/index/art/node16.cpp"

==> duckdb-0.2.7.tar.gz: duckdb-0.2.7/duckdb/amalgamation-1.cpp <==
#include "src/catalog/catalog.cpp"

#include "src/catalog/catalog_entry.cpp"

#include "src/catalog/catalog_entry/copy_function_catalog_entry.cpp"

#include "src/catalog/catalog_entry/index_catalog_entry.cpp"

#include "src/catalog/catalog_entry/macro_catalog_entry.cpp"

#include "src/catalog/catalog_entry/pragma_function_catalog_entry.cpp"

#include "src/catalog/catalog_entry/schema_catalog_entry.cpp"

#include "src/catalog/catalog_entry/sequence_catalog_entry.cpp"

#include "src/catalog/catalog_entry/table_catalog_entry.cpp"

#include "src/catalog/catalog_entry/table_function_catalog_entry.cpp"

#include "src/catalog/catalog_entry/view_catalog_entry.cpp"

#include "src/catalog/catalog_set.cpp"

#include "src/catalog/default/default_functions.cpp"

#include "src/catalog/default/default_schemas.cpp"

#include "src/catalog/default/default_views.cpp"

#include "src/catalog/dependency_manager.cpp"

#include "src/common/allocator.cpp"

#include "src/common/arrow_wrapper.cpp"

#include "src/common/assert.cpp"

#include "src/common/bit_operations.cpp"

#include "src/common/checksum.cpp"

#include "src/common/constants.cpp"

#include "src/common/crypto/md5.cpp"

#include "src/common/cycle_counter.cpp"

#include "src/common/enums/catalog_type.cpp"

#include "src/common/enums/expression_type.cpp"

#include "src/common/enums/join_type.cpp"

#include "src/common/enums/logical_operator_type.cpp"

#include "src/common/enums/physical_operator_type.cpp"

#include "src/common/enums/relation_type.cpp"

#include "src/common/enums/statement_type.cpp"

#include "src/common/exception.cpp"

#include "src/common/exception_format_value.cpp"

#include "src/common/file_buffer.cpp"

#include "src/common/file_system.cpp"

#include "src/common/fstream_util.cpp"

#include "src/common/gzip_file_system.cpp"

#include "src/common/limits.cpp"

#include "src/common/operator/cast_operators.cpp"

#include "src/common/printer.cpp"

#include "src/common/progress_bar.cpp"

#include "src/common/row_operations/row_aggregate.cpp"

#include "src/common/row_operations/row_gather.cpp"

#include "src/common/row_operations/row_match.cpp"

#include "src/common/row_operations/row_scatter.cpp"

#include "src/common/serializer.cpp"

#include "src/common/serializer/buffered_deserializer.cpp"

#include "src/common/serializer/buffered_file_reader.cpp"

#include "src/common/serializer/buffered_file_writer.cpp"

#include "src/common/serializer/buffered_serializer.cpp"

#include "src/common/string_util.cpp"

#include "src/common/tree_renderer.cpp"

#include "src/common/types.cpp"

#include "src/common/types/blob.cpp"

#include "src/common/types/cast_helpers.cpp"

#include "src/common/types/chunk_collection.cpp"

#include "src/common/types/data_chunk.cpp"

#include "src/common/types/date.cpp"

#include "src/common/types/decimal.cpp"

#include "src/common/types/hash.cpp"

#include "src/common/types/hugeint.cpp"

#include "src/common/types/hyperloglog.cpp"

#include "src/common/types/interval.cpp"

#include "src/common/types/row_data_collection.cpp"

#include "src/common/types/row_layout.cpp"

#include "src/common/types/selection_vector.cpp"

#include "src/common/types/string_heap.cpp"

#include "src/common/types/string_type.cpp"

#include "src/common/types/time.cpp"

#include "src/common/types/timestamp.cpp"

#include "src/common/types/validity_mask.cpp"

#include "src/common/types/value.cpp"

#include "src/common/types/vector.cpp"

#include "src/common/types/vector_buffer.cpp"

#include "src/common/types/vector_constants.cpp"

#include "src/common/value_operations/comparison_operations.cpp"

#include "src/common/value_operations/hash.cpp"

#include "src/common/value_operations/numeric_operations.cpp"

#include "src/common/vector_operations/boolean_operators.cpp"

#include "src/common/vector_operations/comparison_operators.cpp"

#include "src/common/vector_operations/generators.cpp"

#include "src/common/vector_operations/is_distinct_from.cpp"

#include "src/common/vector_operations/null_operations.cpp"

#include "src/common/vector_operations/numeric_inplace_operators.cpp"

#include "src/common/vector_operations/vector_cast.cpp"

#include "src/common/vector_operations/vector_copy.cpp"

#include "src/common/vector_operations/vector_hash.cpp"

#include "src/common/vector_operations/vector_storage.cpp"

#include "src/execution/adaptive_filter.cpp"

#include "src/execution/aggregate_hashtable.cpp"

#include "src/execution/base_aggregate_hashtable.cpp"

#include "src/execution/column_binding_resolver.cpp"

#include "src/execution/expression_executor.cpp"

#include "src/execution/expression_executor/execute_between.cpp"

#include "src/execution/expression_executor/execute_case.cpp"

#include "src/execution/expression_executor/execute_cast.cpp"

#include "src/execution/expression_executor/execute_comparison.cpp"

#include "src/execution/expression_executor/execute_conjunction.cpp"

#include "src/execution/expression_executor/execute_constant.cpp"

#include "src/execution/expression_executor/execute_function.cpp"

#include "src/execution/expression_executor/execute_operator.cpp"

#include "src/execution/expression_executor/execute_parameter.cpp"

#include "src/execution/expression_executor/execute_reference.cpp"

#include "src/execution/expression_executor_state.cpp"

#include "src/execution/index/art/art.cpp"

#include "src/execution/index/art/art_key.cpp"

#include "src/execution/index/art/leaf.cpp"

#include "src/execution/index/art/node.cpp"

#include "src/execution/index/art/node16.cpp"
